import { createPinia } from 'pinia'

import router from '@/router'
import Vant from 'vant';

import { setup as setupStorage } from './storage';

// 新增：Capacitor 相关导入
import { App as CapApp } from '@capacitor/app'
import { Browser } from '@capacitor/browser'
 
// 引入组件
import SvgIcon from "@/components/Svg-icon/SvgIcon.vue";


// 新增：Capacitor 初始化逻辑
const initCapacitor = (app) => {
  // Android 返回按钮处理
  CapApp.addListener('backButton', ({ canGoBack }) => {
    if (router.currentRoute.value.path !== '/' && canGoBack) {
      router.back()
    } else {
      CapApp.exitApp()
    }
  })

  // 全局注入 Capacitor 能力
  app.config.globalProperties.$capApp = CapApp
  app.config.globalProperties.$capBrowser = Browser
}


export function setupPlugin(app) {
  // 注入组件
  app.component("SvgIcon", SvgIcon);
  // 插件
  app.use(createPinia());
  app.use(router);
  app.use(Vant);
  

  setupStorage(); 
  // 挂载前初始化
  initCapacitor(app)

}
